@@ -29,18 +29,7 @@ from raylab.utils.types import TensorDict
 @option("optimizer/model", {"lr": 1e-3})
 @option("optimizer/actor", {"lr": 1e-3})
 @option("optimizer/critic", {"lr": 1e-3})
-@option(
-    "vf_loss_coeff",
-    1.0,
-    help="Weight of the fitted V loss in the joint model-value loss",
-)
 @option("max_grad_norm", 10.0, help="Clip gradient norms by this value")
-@option("max_is_ratio", 5.0, help="Clip importance sampling weights by this value")
-@option(
-    "polyak",
-    0.995,
-    help="Interpolation factor in polyak averaging for target networks.",
-)
 @option(
     "replay_kl",
     True,
@@ -65,9 +54,7 @@ class SVGOneTorchPolicy(OffPolicyMixin, AdaptiveKLCoeffMixin, SVGTorchPolicy):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.loss_actor = OneStepSVG(
-            lambda s, a, s_: self.module.model.reproduce(s_, self.module.model(s, a)),
-            self.module.actor.reproduce,
-            self.module.critic,
+            self.module.model, self.module.actor, self.module.critic
         )
         self.loss_actor.gamma = self.config["gamma"]
 
