@@ -9,27 +9,29 @@ from ray.rllib import SampleBatch
 from ray.rllib.utils import override
 from torch import Tensor
 
+from raylab.policy.modules.actor import Alpha
 from raylab.policy.modules.actor import StochasticPolicy
+from raylab.policy.modules.critic import VValue
 from raylab.policy.modules.model import StochasticModel
-from raylab.utils.dictionaries import get_keys
 from raylab.utils.types import RewardFn
 from raylab.utils.types import StatDict
 from raylab.utils.types import TensorDict
 
 from .abstract import Loss
+from .mixins import EnvFunctionsMixin
 
 
 StateRepr = Callable[[Tensor, Tensor, Tensor], Tuple[Tensor, Tensor]]
 ActionRepr = Callable[[Tensor, Tensor], Tuple[Tensor, Tensor]]
 
 
-class OneStepSVG(Loss):
+class OneStepSVG(EnvFunctionsMixin, Loss):
     """Loss function for Stochastic Value Gradients with 1-step bootstrapping.
 
     Args:
-        model: stochastic model that reproduces state and its log density
-        actor: stochastic policy that reproduces action and its log density
-        critic: state-value function
+        model: Stochastic model that reproduces state and its log density
+        actor: Stochastic policy that reproduces action and its log density
+        critic: State-value function
 
     Attributes:
         gamma: discount factor
@@ -39,7 +41,8 @@ class OneStepSVG(Loss):
     gamma: float = 0.99
     batch_keys: Tuple[str, str, str, str, str]
 
-    def __init__(self, model: StateRepr, actor: ActionRepr, critic: nn.Module):
+    def __init__(self, model: StochasticModel, actor: StochasticPolicy, critic: VValue):
+        super().__init__()
         self.model = model
         self.actor = actor
         self.critic = critic
@@ -51,26 +54,12 @@ class OneStepSVG(Loss):
             SampleBatch.DONES,
             self.IS_RATIOS,
         )
-        self._reward_fn = None
-
-    def set_reward_fn(self, function: RewardFn):
-        """Set reward function to provided callable."""
-        self._reward_fn = function
 
     def __call__(self, batch: TensorDict) -> Tuple[Tensor, StatDict]:
         """Compute bootstrapped Stochatic Value Gradient loss."""
-        assert (
-            self._reward_fn is not None
-        ), "No reward function set. Did you call `set_reward_fn`?"
+        assert self._env.reward is not None, "Reward function must be set!"
+        obs, actions, next_obs, dones, is_ratios = self.unpack_batch(batch)
 
-        obs, actions, next_obs, dones, is_ratios = get_keys(
-            batch,
-            SampleBatch.CUR_OBS,
-            SampleBatch.ACTIONS,
-            SampleBatch.NEXT_OBS,
-            SampleBatch.DONES,
-            self.IS_RATIOS,
-        )
         state_val = self.one_step_reproduced_state_value(obs, actions, next_obs, dones)
         svg_loss = -torch.mean(is_ratios * state_val)
         return svg_loss, {"loss(actor)": svg_loss.item()}
@@ -79,10 +68,10 @@ class OneStepSVG(Loss):
         self, obs: Tensor, actions: Tensor, next_obs: Tensor, dones: Tensor
     ) -> Tensor:
         """Compute 1-step approximation of the state value on real transition."""
-        _acts, _ = self.actor(obs, actions)
-        _next_obs, _ = self.model(obs, _acts, next_obs)
-        _rewards = self._reward_fn(obs, _acts, _next_obs)
-        _next_vals = self.critic(_next_obs).squeeze(-1)
+        _acts, _ = self.actor.reproduce(obs, actions)
+        _next_obs, _ = self.model.reproduce(next_obs, self.model(obs, _acts))
+        _rewards = self._env.reward(obs, _acts, _next_obs)
+        _next_vals = self.critic(_next_obs)
         return torch.where(dones, _rewards, _rewards + self.gamma * _next_vals)
 
 
@@ -90,28 +79,37 @@ class OneStepSoftSVG(OneStepSVG):
     """Loss function for bootstrapped maximum entropy Stochastic Value Gradients.
 
     Args:
-        model: stochastic model that reproduces state and its log density
-        actor: stochastic policy that reproduces action and its log density
-        critic: state-value function
+        model: Stochastic model that reproduces state and its log density
+        actor: Stochastic policy that reproduces action and its log density
+        critic: State-value function
+        alpha: Entropy coefficient
 
     Attributes:
-        gamma: discount factor
-        alpha: entropy coefficient
+        gamma: Discount factor
     """
 
     gamma: float = 0.99
-    alpha: float = 0.05
+
+    def __init__(
+        self,
+        model: StochasticModel,
+        actor: StochasticPolicy,
+        critic: VValue,
+        alpha: Alpha,
+    ):
+        self.alpha = alpha
+        super().__init__(model, actor, critic)
 
     @override(OneStepSVG)
     def one_step_reproduced_state_value(
         self, obs: Tensor, actions: Tensor, next_obs: Tensor, dones: Tensor
     ) -> Tensor:
-        _actions, _logp = self.actor(obs, actions)
-        _next_obs, _ = self.model(obs, _actions, next_obs)
-        _rewards = self._reward_fn(obs, _actions, _next_obs)
+        _actions, _logp = self.actor.reproduce(obs, actions)
+        _next_obs, _ = self.model.reproduce(next_obs, self.model(obs, _actions))
+        _rewards = self._env.reward(obs, _actions, _next_obs)
         _entropy = -_logp
-        _augmented_rewards = _rewards + _entropy * self.alpha
-        _next_vals = self.critic(_next_obs).squeeze(-1)
+        _augmented_rewards = _rewards + _entropy * self.alpha()
+        _next_vals = self.critic(_next_obs)
 
         return torch.where(
             dones,
@@ -120,7 +118,7 @@ class OneStepSoftSVG(OneStepSVG):
         )
 
 
-class TrajectorySVG(Loss):
+class TrajectorySVG(EnvFunctionsMixin, Loss):
     """Loss function for Stochastic Value Gradients on full trajectory.
 
     Args:
@@ -129,24 +127,23 @@ class TrajectorySVG(Loss):
         critic: state-value function
     """
 
-    batch_keys = (
+    batch_keys: Tuple[str, str, str] = (
         SampleBatch.CUR_OBS,
         SampleBatch.ACTIONS,
         SampleBatch.NEXT_OBS,
     )
 
-    def __init__(
-        self, model: StochasticModel, actor: StochasticPolicy, critic: nn.Module
-    ):
+    def __init__(self, model: StochasticModel, actor: StochasticPolicy, critic: VValue):
+        super().__init__()
         self.model = model
         self.actor = actor
         self.critic = critic
 
         self._rollout = None
 
-    def set_reward_fn(self, function: RewardFn):
-        """Set reward function to provided callable."""
-        self._rollout = ReproduceRewards(self.actor, self.model, function)
+    def set_reward_fn(self, *args, **kwargs):
+        super().set_reward_fn(*args, **kwargs)
+        self._rollout = ReproduceRewards(self.actor, self.model, self._env.reward)
 
     def compile(self):
         """Compile the rollout module to TorchScript."""
@@ -164,7 +161,7 @@ class TrajectorySVG(Loss):
             actions = episode[SampleBatch.ACTIONS]
             next_obs = episode[SampleBatch.NEXT_OBS]
 
-            rewards = self._rollout(actions, next_obs, init_obs)
+            _, _, rewards = self._rollout(actions, next_obs, init_obs)
             total_ret += rewards.sum()
 
         sim_return_mean = total_ret / len(episodes)
@@ -182,6 +179,7 @@ class ReproduceRewards(nn.Module):
         reward_fn: reward function for state, action, and next state tuples
     """
 
+    # pylint:disable=abstract-method
     def __init__(
         self, policy: StochasticPolicy, model: StochasticModel, reward_fn: RewardFn
     ):
@@ -191,7 +189,9 @@ class ReproduceRewards(nn.Module):
         self.reward_fn = reward_fn
 
     @override(nn.Module)
-    def forward(self, acts: Tensor, next_obs: Tensor, init_ob: Tensor) -> Tensor:
+    def forward(
+        self, acts: Tensor, next_obs: Tensor, init_ob: Tensor
+    ) -> Tuple[Tensor, Tensor, Tensor]:
         """Reproduce a sequence of actions, obsevations, and rewards.
 
         Args:
@@ -201,17 +201,22 @@ class ReproduceRewards(nn.Module):
             init_ob: the initial observation
 
         Returns:
-            The rewards from the reproduced action sequence
+            The observations, actions and rewards from the reproduced trajectory
 
         Note:
             Assumes the first tensor dimension of `acts` and `next_obs`
             corresponds to the timestep and iterates over it.
         """
         # pylint:disable=arguments-differ
+        obs_seq = []
+        act_seq = []
         reward_seq = []
+        cur_ob = init_ob
         for act, next_ob in zip(acts, next_obs):
-            _act, _ = self.policy.reproduce(init_ob, act)
-            _next_ob, _ = self.model.reproduce(next_ob, self.model(init_ob, _act))
-            reward_seq.append(self.reward_fn(init_ob, _act, _next_ob))
-            init_ob = _next_ob
-        return torch.stack(reward_seq)
+            _act, _ = self.policy.reproduce(cur_ob, act)
+            act_seq += [_act]
+            _next_ob, _ = self.model.reproduce(next_ob, self.model(cur_ob, _act))
+            obs_seq += [_next_ob]
+            reward_seq += [self.reward_fn(cur_ob, _act, _next_ob)]
+            cur_ob = _next_ob
+        return torch.stack(obs_seq), torch.stack(act_seq), torch.stack(reward_seq)
